@@ -4,14 +4,14 @@ Main interface for wafv2 service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_wafv2.type_defs import AndStatementTypeDef
+    from mypy_boto3_wafv2.type_defs import ActionConditionTypeDef
 
-    data: AndStatementTypeDef = {...}
+    data: ActionConditionTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import IO, Any, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -24,11 +24,21 @@ else:
 
 
 __all__ = (
+    "ActionConditionTypeDef",
+    "AllowActionTypeDef",
     "AndStatementTypeDef",
+    "BlockActionTypeDef",
     "ByteMatchStatementTypeDef",
+    "ConditionTypeDef",
+    "CountActionTypeDef",
+    "CustomHTTPHeaderTypeDef",
+    "CustomRequestHandlingTypeDef",
+    "CustomResponseBodyTypeDef",
+    "CustomResponseTypeDef",
     "DefaultActionTypeDef",
     "ExcludedRuleTypeDef",
     "FieldToMatchTypeDef",
+    "FilterTypeDef",
     "FirewallManagerRuleGroupTypeDef",
     "FirewallManagerStatementTypeDef",
     "ForwardedIPConfigTypeDef",
@@ -39,7 +49,14 @@ __all__ = (
     "IPSetReferenceStatementTypeDef",
     "IPSetSummaryTypeDef",
     "IPSetTypeDef",
+    "JsonBodyTypeDef",
+    "JsonMatchPatternTypeDef",
+    "LabelMatchStatementTypeDef",
+    "LabelNameConditionTypeDef",
+    "LabelSummaryTypeDef",
+    "LabelTypeDef",
     "LoggingConfigurationTypeDef",
+    "LoggingFilterTypeDef",
     "ManagedRuleGroupStatementTypeDef",
     "ManagedRuleGroupSummaryTypeDef",
     "NotStatementTypeDef",
@@ -102,12 +119,24 @@ __all__ = (
     "UpdateWebACLResponseTypeDef",
 )
 
+ActionConditionTypeDef = TypedDict(
+    "ActionConditionTypeDef", {"Action": Literal["ALLOW", "BLOCK", "COUNT"]}
+)
+
+AllowActionTypeDef = TypedDict(
+    "AllowActionTypeDef", {"CustomRequestHandling": "CustomRequestHandlingTypeDef"}, total=False
+)
+
 AndStatementTypeDef = TypedDict("AndStatementTypeDef", {"Statements": List[Dict[str, Any]]})
 
+BlockActionTypeDef = TypedDict(
+    "BlockActionTypeDef", {"CustomResponse": "CustomResponseTypeDef"}, total=False
+)
+
 ByteMatchStatementTypeDef = TypedDict(
     "ByteMatchStatementTypeDef",
     {
-        "SearchString": bytes,
+        "SearchString": Union[bytes, IO[bytes]],
         "FieldToMatch": "FieldToMatchTypeDef",
         "TextTransformations": List["TextTransformationTypeDef"],
         "PositionalConstraint": Literal[
@@ -116,8 +145,46 @@ ByteMatchStatementTypeDef = TypedDict(
     },
 )
 
+ConditionTypeDef = TypedDict(
+    "ConditionTypeDef",
+    {
+        "ActionCondition": "ActionConditionTypeDef",
+        "LabelNameCondition": "LabelNameConditionTypeDef",
+    },
+    total=False,
+)
+
+CountActionTypeDef = TypedDict(
+    "CountActionTypeDef", {"CustomRequestHandling": "CustomRequestHandlingTypeDef"}, total=False
+)
+
+CustomHTTPHeaderTypeDef = TypedDict("CustomHTTPHeaderTypeDef", {"Name": str, "Value": str})
+
+CustomRequestHandlingTypeDef = TypedDict(
+    "CustomRequestHandlingTypeDef", {"InsertHeaders": List["CustomHTTPHeaderTypeDef"]}
+)
+
+CustomResponseBodyTypeDef = TypedDict(
+    "CustomResponseBodyTypeDef",
+    {"ContentType": Literal["TEXT_PLAIN", "TEXT_HTML", "APPLICATION_JSON"], "Content": str},
+)
+
+_RequiredCustomResponseTypeDef = TypedDict("_RequiredCustomResponseTypeDef", {"ResponseCode": int})
+_OptionalCustomResponseTypeDef = TypedDict(
+    "_OptionalCustomResponseTypeDef",
+    {"CustomResponseBodyKey": str, "ResponseHeaders": List["CustomHTTPHeaderTypeDef"]},
+    total=False,
+)
+
+
+class CustomResponseTypeDef(_RequiredCustomResponseTypeDef, _OptionalCustomResponseTypeDef):
+    pass
+
+
 DefaultActionTypeDef = TypedDict(
-    "DefaultActionTypeDef", {"Block": Dict[str, Any], "Allow": Dict[str, Any]}, total=False
+    "DefaultActionTypeDef",
+    {"Block": "BlockActionTypeDef", "Allow": "AllowActionTypeDef"},
+    total=False,
 )
 
 ExcludedRuleTypeDef = TypedDict("ExcludedRuleTypeDef", {"Name": str})
@@ -132,10 +199,20 @@ FieldToMatchTypeDef = TypedDict(
         "QueryString": Dict[str, Any],
         "Body": Dict[str, Any],
         "Method": Dict[str, Any],
+        "JsonBody": "JsonBodyTypeDef",
     },
     total=False,
 )
 
+FilterTypeDef = TypedDict(
+    "FilterTypeDef",
+    {
+        "Behavior": Literal["KEEP", "DROP"],
+        "Requirement": Literal["MEETS_ALL", "MEETS_ANY"],
+        "Conditions": List["ConditionTypeDef"],
+    },
+)
+
 FirewallManagerRuleGroupTypeDef = TypedDict(
     "FirewallManagerRuleGroupTypeDef",
     {
@@ -485,12 +562,45 @@ class IPSetTypeDef(_RequiredIPSetTypeDef, _OptionalIPSetTypeDef):
     pass
 
 
+_RequiredJsonBodyTypeDef = TypedDict(
+    "_RequiredJsonBodyTypeDef",
+    {"MatchPattern": "JsonMatchPatternTypeDef", "MatchScope": Literal["ALL", "KEY", "VALUE"]},
+)
+_OptionalJsonBodyTypeDef = TypedDict(
+    "_OptionalJsonBodyTypeDef",
+    {"InvalidFallbackBehavior": Literal["MATCH", "NO_MATCH", "EVALUATE_AS_STRING"]},
+    total=False,
+)
+
+
+class JsonBodyTypeDef(_RequiredJsonBodyTypeDef, _OptionalJsonBodyTypeDef):
+    pass
+
+
+JsonMatchPatternTypeDef = TypedDict(
+    "JsonMatchPatternTypeDef", {"All": Dict[str, Any], "IncludedPaths": List[str]}, total=False
+)
+
+LabelMatchStatementTypeDef = TypedDict(
+    "LabelMatchStatementTypeDef", {"Scope": Literal["LABEL", "NAMESPACE"], "Key": str}
+)
+
+LabelNameConditionTypeDef = TypedDict("LabelNameConditionTypeDef", {"LabelName": str})
+
+LabelSummaryTypeDef = TypedDict("LabelSummaryTypeDef", {"Name": str}, total=False)
+
+LabelTypeDef = TypedDict("LabelTypeDef", {"Name": str})
+
 _RequiredLoggingConfigurationTypeDef = TypedDict(
     "_RequiredLoggingConfigurationTypeDef", {"ResourceArn": str, "LogDestinationConfigs": List[str]}
 )
 _OptionalLoggingConfigurationTypeDef = TypedDict(
     "_OptionalLoggingConfigurationTypeDef",
-    {"RedactedFields": List["FieldToMatchTypeDef"], "ManagedByFirewallManager": bool},
+    {
+        "RedactedFields": List["FieldToMatchTypeDef"],
+        "ManagedByFirewallManager": bool,
+        "LoggingFilter": "LoggingFilterTypeDef",
+    },
     total=False,
 )
 
@@ -501,12 +611,17 @@ class LoggingConfigurationTypeDef(
     pass
 
 
+LoggingFilterTypeDef = TypedDict(
+    "LoggingFilterTypeDef",
+    {"Filters": List["FilterTypeDef"], "DefaultBehavior": Literal["KEEP", "DROP"]},
+)
+
 _RequiredManagedRuleGroupStatementTypeDef = TypedDict(
     "_RequiredManagedRuleGroupStatementTypeDef", {"VendorName": str, "Name": str}
 )
 _OptionalManagedRuleGroupStatementTypeDef = TypedDict(
     "_OptionalManagedRuleGroupStatementTypeDef",
-    {"ExcludedRules": List["ExcludedRuleTypeDef"]},
+    {"ExcludedRules": List["ExcludedRuleTypeDef"], "ScopeDownStatement": Dict[str, Any]},
     total=False,
 )
 
@@ -528,7 +643,7 @@ NotStatementTypeDef = TypedDict("NotStatementTypeDef", {"Statement": Dict[str, A
 OrStatementTypeDef = TypedDict("OrStatementTypeDef", {"Statements": List[Dict[str, Any]]})
 
 OverrideActionTypeDef = TypedDict(
-    "OverrideActionTypeDef", {"Count": Dict[str, Any], "None": Dict[str, Any]}, total=False
+    "OverrideActionTypeDef", {"Count": "CountActionTypeDef", "None": Dict[str, Any]}, total=False
 )
 
 RateBasedStatementManagedKeysIPSetTypeDef = TypedDict(
@@ -585,7 +700,7 @@ RegexTypeDef = TypedDict("RegexTypeDef", {"RegexString": str}, total=False)
 
 RuleActionTypeDef = TypedDict(
     "RuleActionTypeDef",
-    {"Block": Dict[str, Any], "Allow": Dict[str, Any], "Count": Dict[str, Any]},
+    {"Block": "BlockActionTypeDef", "Allow": "AllowActionTypeDef", "Count": "CountActionTypeDef"},
     total=False,
 )
 
@@ -622,7 +737,16 @@ _RequiredRuleGroupTypeDef = TypedDict(
     },
 )
 _OptionalRuleGroupTypeDef = TypedDict(
-    "_OptionalRuleGroupTypeDef", {"Description": str, "Rules": List["RuleTypeDef"]}, total=False
+    "_OptionalRuleGroupTypeDef",
+    {
+        "Description": str,
+        "Rules": List["RuleTypeDef"],
+        "LabelNamespace": str,
+        "CustomResponseBodies": Dict[str, "CustomResponseBodyTypeDef"],
+        "AvailableLabels": List["LabelSummaryTypeDef"],
+        "ConsumedLabels": List["LabelSummaryTypeDef"],
+    },
+    total=False,
 )
 
 
@@ -645,7 +769,11 @@ _RequiredRuleTypeDef = TypedDict(
 )
 _OptionalRuleTypeDef = TypedDict(
     "_OptionalRuleTypeDef",
-    {"Action": "RuleActionTypeDef", "OverrideAction": "OverrideActionTypeDef"},
+    {
+        "Action": "RuleActionTypeDef",
+        "OverrideAction": "OverrideActionTypeDef",
+        "RuleLabels": List["LabelTypeDef"],
+    },
     total=False,
 )
 
@@ -659,7 +787,14 @@ _RequiredSampledHTTPRequestTypeDef = TypedDict(
 )
 _OptionalSampledHTTPRequestTypeDef = TypedDict(
     "_OptionalSampledHTTPRequestTypeDef",
-    {"Timestamp": datetime, "Action": str, "RuleNameWithinRuleGroup": str},
+    {
+        "Timestamp": datetime,
+        "Action": str,
+        "RuleNameWithinRuleGroup": str,
+        "RequestHeadersInserted": List["HTTPHeaderTypeDef"],
+        "ResponseCodeSent": int,
+        "Labels": List["LabelTypeDef"],
+    },
     total=False,
 )
 
@@ -745,6 +880,8 @@ _OptionalWebACLTypeDef = TypedDict(
         "PreProcessFirewallManagerRuleGroups": List["FirewallManagerRuleGroupTypeDef"],
         "PostProcessFirewallManagerRuleGroups": List["FirewallManagerRuleGroupTypeDef"],
         "ManagedByFirewallManager": bool,
+        "LabelNamespace": str,
+        "CustomResponseBodies": Dict[str, "CustomResponseBodyTypeDef"],
     },
     total=False,
 )
@@ -790,7 +927,13 @@ DeleteFirewallManagerRuleGroupsResponseTypeDef = TypedDict(
 
 DescribeManagedRuleGroupResponseTypeDef = TypedDict(
     "DescribeManagedRuleGroupResponseTypeDef",
-    {"Capacity": int, "Rules": List["RuleSummaryTypeDef"]},
+    {
+        "Capacity": int,
+        "Rules": List["RuleSummaryTypeDef"],
+        "LabelNamespace": str,
+        "AvailableLabels": List["LabelSummaryTypeDef"],
+        "ConsumedLabels": List["LabelSummaryTypeDef"],
+    },
     total=False,
 )
 
@@ -810,6 +953,7 @@ StatementTypeDef = TypedDict(
         "OrStatement": "OrStatementTypeDef",
         "NotStatement": "NotStatementTypeDef",
         "ManagedRuleGroupStatement": "ManagedRuleGroupStatementTypeDef",
+        "LabelMatchStatement": "LabelMatchStatementTypeDef",
     },
     total=False,
 )
